summaryrefslogtreecommitdiffstats
path: root/src/include
diff options
context:
space:
mode:
authorStephen Cprek <smcprek@us.ibm.com>2017-11-17 15:49:30 -0600
committerDaniel M. Crowell <dcrowell@us.ibm.com>2017-11-30 09:08:08 -0500
commitc336a77283197bd63475f0773b78473c7c239567 (patch)
tree9cd1c13e5e106541c9e1914865aef18082f27187 /src/include
parent4c1c57f0015efea51fb6c47ded6a6ec05ed27978 (diff)
downloadtalos-hostboot-c336a77283197bd63475f0773b78473c7c239567.tar.gz
talos-hostboot-c336a77283197bd63475f0773b78473c7c239567.zip
Handle comments from pre-verify and runtime lid loading commits
Change-Id: I224079808493c062f04b7c3a59d45128a8f2e699 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/49875 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Reviewed-by: Michael Baiocchi <mbaiocch@us.ibm.com> Reviewed-by: Nicholas E. Bofferding <bofferdn@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP HW <op-hw-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/include')
-rw-r--r--src/include/usr/runtime/common/runtime_utils.H3
-rw-r--r--src/include/usr/runtime/populate_hbruntime.H8
-rw-r--r--src/include/usr/secureboot/containerheader.H2
3 files changed, 8 insertions, 5 deletions
diff --git a/src/include/usr/runtime/common/runtime_utils.H b/src/include/usr/runtime/common/runtime_utils.H
index c7f318bc1..afb88bd47 100644
--- a/src/include/usr/runtime/common/runtime_utils.H
+++ b/src/include/usr/runtime/common/runtime_utils.H
@@ -29,7 +29,10 @@
namespace RUNTIME
{
+// Pair indicating if a PNOR section is expected to have a secure header
+// regardless of the compiler options
typedef std::pair<PNOR::SectionId, bool> PreVerifyPair;
+// A vector of all PNOR sections that are pre-verified for runtime
typedef std::vector<PreVerifyPair> PreVerifyVector;
// PNOR sections that will be pre-verified and loaded into HB reserved memory
diff --git a/src/include/usr/secureboot/containerheader.H b/src/include/usr/secureboot/containerheader.H
index f7e924d9b..b5edfb325 100644
--- a/src/include/usr/secureboot/containerheader.H
+++ b/src/include/usr/secureboot/containerheader.H
@@ -63,7 +63,7 @@ class ContainerHeader
};
/**
- * @brief ContainerHeader
+ * @brief ContainerHeader - generate fake header
*
* This constructor generates a fake header with minimal information
*
OpenPOWER on IntegriCloud
diff --git a/src/include/usr/runtime/populate_hbruntime.H b/src/include/usr/runtime/populate_hbruntime.H
index 9f0466172..c2c0c224e 100644
--- a/src/include/usr/runtime/populate_hbruntime.H
+++ b/src/include/usr/runtime/populate_hbruntime.H
@@ -70,13 +70,13 @@ errlHndl_t unmapVirtAddr(uint64_t i_addr);
* @brief Pre verify Pnor sections and load into HB reserved memory
*
* @param[in] i_sec - pnor section to pre-verify and load
* @param[in] i_verified - Indicates if pnor section is expected to have a
* secure header.
* e.g. RINGOVD currently never has a secure header
*
* @return Error handle if error
*/
errlHndl_t hbResvLoadSecureSection (const PNOR::SectionId i_sec,
- const bool i_verified);
+ const bool i_secHdrExpected);
} // End of Namespace \ No newline at end of file
@@ -70,13 +70,13 @@ errlHndl_t unmapVirtAddr(uint64_t i_addr);
*
* @param[in] i_sec - pnor section to pre-verify and load
- * @param[in] i_verified - Indicates if pnor section is expected to have a
- * secure header.
- * e.g. RINGOVD currently never has a secure header
+ * @param[in] i_secHdrExpected - Indicates if pnor section is expected to have
+ * a secure header.
+ * e.g. RINGOVD currently never has a secure header
*
* @return Error handle if error